@@ -22,6 +22,7 @@ fn run_flow_private() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
 
     let mut task = Task::new();
@@ -46,7 +47,7 @@ fn run_flow_private() {
         cli_arguments: None,
     };
 
-    run_flow(&flow_info, &mut FlowState::new(), false);
+    run_flow(&flow_info, Rc::new(RefCell::new(FlowState::new())), false);
 }
 
 #[test]
@@ -58,6 +59,7 @@ fn run_flow_private_skipped() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
 
     let mut task = Task::new();
@@ -82,7 +84,7 @@ fn run_flow_private_skipped() {
         cli_arguments: None,
     };
 
-    run_flow(&flow_info, &mut FlowState::new(), false);
+    run_flow(&flow_info, Rc::new(RefCell::new(FlowState::new())), false);
 }
 
 #[test]
@@ -94,6 +96,7 @@ fn run_flow_private_sub_task() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
 
     let mut task = Task::new();
@@ -118,7 +121,7 @@ fn run_flow_private_sub_task() {
         cli_arguments: None,
     };
 
-    run_flow(&flow_info, &mut FlowState::new(), true);
+    run_flow(&flow_info, Rc::new(RefCell::new(FlowState::new())), true);
 }
 
 #[test]
@@ -130,6 +133,7 @@ fn run_flow_allow_private() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
 
     let mut task = Task::new();
@@ -154,7 +158,7 @@ fn run_flow_allow_private() {
         cli_arguments: None,
     };
 
-    run_flow(&flow_info, &mut FlowState::new(), false);
+    run_flow(&flow_info, Rc::new(RefCell::new(FlowState::new())), false);
 }
 
 #[test]
@@ -167,6 +171,7 @@ fn run_task_bad_script() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -192,7 +197,7 @@ fn run_task_bad_script() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -206,6 +211,7 @@ fn run_task_script_with_args_error() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -231,7 +237,7 @@ fn run_task_script_with_args_error() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -244,6 +250,7 @@ fn run_task_script_with_args_valid() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -269,7 +276,7 @@ fn run_task_script_with_args_valid() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -281,6 +288,7 @@ fn run_task_command() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -307,7 +315,7 @@ fn run_task_command() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -320,6 +328,7 @@ fn run_task_bad_command_valid_script() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -346,7 +355,7 @@ fn run_task_bad_command_valid_script() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -358,6 +367,7 @@ fn run_task_no_command_valid_script() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -383,7 +393,7 @@ fn run_task_no_command_valid_script() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -402,6 +412,7 @@ fn run_task_bad_run_task_valid_command() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -429,7 +440,7 @@ fn run_task_bad_run_task_valid_command() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -447,6 +458,7 @@ fn run_task_valid_run_task() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -472,7 +484,7 @@ fn run_task_valid_run_task() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -485,6 +497,7 @@ fn run_task_invalid_task() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -511,7 +524,7 @@ fn run_task_invalid_task() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -523,6 +536,7 @@ fn run_task_set_env_file() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -559,7 +573,7 @@ fn run_task_set_env_file() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 
     assert_eq!(envmnt::get_or_panic("CARGO_MAKE_ENV_FILE_TEST1"), "1");
 
@@ -577,6 +591,7 @@ fn run_task_set_env() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -612,7 +627,7 @@ fn run_task_set_env() {
 
     envmnt::set("TEST_RUN_TASK_SET_ENV", "EMPTY");
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 
     assert_eq!(envmnt::get_or_panic("TEST_RUN_TASK_SET_ENV"), "VALID");
 }
@@ -627,6 +642,7 @@ fn run_task_cwd_no_such_dir() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -653,7 +669,7 @@ fn run_task_cwd_no_such_dir() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -665,6 +681,7 @@ fn run_task_cwd_dir_exists() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -691,7 +708,7 @@ fn run_task_cwd_dir_exists() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -703,6 +720,7 @@ fn run_task_cwd_env_expansion() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -729,7 +747,7 @@ fn run_task_cwd_env_expansion() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -741,6 +759,7 @@ fn run_task_deprecated_message() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -768,7 +787,7 @@ fn run_task_deprecated_message() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -780,6 +799,7 @@ fn run_task_deprecated_flag() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -807,7 +827,7 @@ fn run_task_deprecated_flag() {
         config: task,
     };
 
-    run_task(&flow_info, &mut FlowState::new(), &step);
+    run_task(&flow_info, Rc::new(RefCell::new(FlowState::new())), &step);
 }
 
 #[test]
@@ -1288,6 +1308,7 @@ fn run_sub_task_and_report_for_name() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1308,7 +1329,11 @@ fn run_sub_task_and_report_for_name() {
 
     let sub_task = RunTaskInfo::Name("test".to_string());
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(output);
 }
@@ -1329,6 +1354,7 @@ fn run_sub_task_and_report_for_name_not_found() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1349,7 +1375,11 @@ fn run_sub_task_and_report_for_name_not_found() {
 
     let sub_task = RunTaskInfo::Name("test2".to_string());
 
-    run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 }
 
 #[test]
@@ -1367,6 +1397,7 @@ fn run_sub_task_and_report_for_details_single() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1392,7 +1423,11 @@ fn run_sub_task_and_report_for_details_single() {
         cleanup_task: None,
     });
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(output);
 }
@@ -1413,6 +1448,7 @@ fn run_sub_task_and_report_for_details_multiple() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1438,7 +1474,11 @@ fn run_sub_task_and_report_for_details_multiple() {
         cleanup_task: None,
     });
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(output);
 }
@@ -1458,6 +1498,7 @@ fn run_sub_task_and_report_routing_empty() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1478,7 +1519,11 @@ fn run_sub_task_and_report_routing_empty() {
 
     let sub_task = RunTaskInfo::Routing(vec![]);
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(!output);
 }
@@ -1498,6 +1543,7 @@ fn run_sub_task_and_report_routing_no_condition() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1525,7 +1571,11 @@ fn run_sub_task_and_report_routing_no_condition() {
         condition_script: None,
     }]);
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(output);
 }
@@ -1545,6 +1595,7 @@ fn run_sub_task_and_report_routing_condition_not_met() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1586,7 +1637,11 @@ fn run_sub_task_and_report_routing_condition_not_met() {
         condition_script: None,
     }]);
 
-    let output = run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    let output = run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 
     assert!(!output);
 }
@@ -1607,6 +1662,7 @@ fn run_sub_task_and_report_routing_not_found() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1634,7 +1690,11 @@ fn run_sub_task_and_report_routing_not_found() {
         condition_script: None,
     }]);
 
-    run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 }
 
 #[test]
@@ -1653,6 +1713,7 @@ fn run_sub_task_and_report_with_cleanup_task_but_no_fork() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks,
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1678,7 +1739,11 @@ fn run_sub_task_and_report_with_cleanup_task_but_no_fork() {
         cleanup_task: Some("test".to_string()),
     });
 
-    run_sub_task_and_report(&flow_info, &mut FlowState::new(), &sub_task);
+    run_sub_task_and_report(
+        &flow_info,
+        Rc::new(RefCell::new(FlowState::new())),
+        &sub_task,
+    );
 }
 
 #[test]
@@ -1689,6 +1754,7 @@ fn get_sub_task_info_for_routing_info_empty() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1724,6 +1790,7 @@ fn get_sub_task_info_for_routing_info_condition_not_met() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1782,6 +1849,7 @@ fn get_sub_task_info_for_routing_info_condition_found() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1840,6 +1908,7 @@ fn get_sub_task_info_for_routing_info_condition_found_multiple_tasks() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1898,6 +1967,7 @@ fn get_sub_task_info_for_routing_info_script_not_met() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1942,6 +2012,7 @@ fn get_sub_task_info_for_routing_info_script_found() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -1986,6 +2057,7 @@ fn get_sub_task_info_for_routing_info_multiple_found() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -2054,6 +2126,7 @@ fn get_sub_task_info_for_routing_info_default() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -2130,6 +2203,7 @@ fn get_sub_task_info_for_routing_info_multiple() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -2214,6 +2288,7 @@ fn get_sub_task_info_for_routing_info_fork_false() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -2272,6 +2347,7 @@ fn get_sub_task_info_for_routing_info_fork_true() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
@@ -2330,6 +2406,7 @@ fn create_fork_step_valid() {
         env: IndexMap::new(),
         env_scripts: vec![],
         tasks: IndexMap::new(),
+        plugins: None,
     };
     let flow_info = FlowInfo {
         config,
